OMAS: Ordered Multidimensional Array Structures
===============================================

.. figure:: images/omas_concept.png
  :align: center
  :width: 95%
  :alt: OMAS simplifies the interface between third-party codes with ITER IMAS
  :target: https://omfit.io/

OMAS is a Python library to interface with the `ITER <http://iter.org>`_ Integrated Modeling and Analysis Suite (`IMAS <https://confluence.iter.org/display/IMP>`_):

* Store data compatibly with the IMAS data model

* Offers convenient services/features beyond data storage

* Does not require a local IMAS installation

Learn More:

* `Video of a talk <https://youtu.be/kGVbEu1dG4c>`_ given at the 2020 American Physical Society meeting and associated `slides <https://www.dropbox.com/s/n0i5yc0kv0vehgc/OMAS_APS2020.pdf?dl=0>`_

* Read more details in the appendix of `"Meneghini et al. Nuclear Fusion (2020)" <https://iopscience.iop.org/article/10.1088/1741-4326/abb918/meta>`_ publication.

---------------------------------

.. image:: https://img.shields.io/github/tag-date/gafusion/omas.svg?label=OMAS&color=blue
  :target: https://github.com/gafusion/omas

.. image:: https://img.shields.io/badge/IMAS-3.31.0-yellow
  :target: https://imas.iter.org

.. image:: https://img.shields.io/travis/gafusion/omas.svg
  :target: https://travis-ci.org/gafusion/omas

.. image:: https://img.shields.io/codecov/c/github/gafusion/omas.svg
  :target: https://codecov.io/gh/gafusion/omas

.. image:: https://img.shields.io/github/repo-size/gafusion/omas.svg?color=blue
  :target: https://github.com/gafusion/omas

---------------------------------
